==> mgug4120a.db_2.0.2.tar.gz: mgug4120a.db/man/mgug4120a_dbconn.Rd <==
\name{mgug4120a_dbconn}

\alias{mgug4120a_dbconn}
\alias{mgug4120a_dbfile}
\alias{mgug4120a_dbschema}
\alias{mgug4120a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mgug4120a_dbconn()
  mgug4120a_dbfile()
  mgug4120a_dbschema(file="", show.indices=FALSE)
  mgug4120a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mgug4120a_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mgug4120a_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mgug4120a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mgug4120a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mgug4120a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mgug4120a_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mgug4120a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mgug4120a_dbschema}: none (invisible \code{NULL}).

  \code{mgug4120a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mgug4120a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mgug4120a_dbconn() was created with:
  dbConnect(SQLite(), dbname=mgug4120a_dbfile(), cache_size=64000, synchronous=0)

  mgug4120a_dbschema()

  mgug4120a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mgug4120a.db_2.9.0.tar.gz: mgug4120a.db/man/mgug4120a_dbconn.Rd <==

\name{mgug4120a_dbconn}

\alias{mgug4120a_dbconn}
\alias{mgug4120a_dbfile}
\alias{mgug4120a_dbschema}
\alias{mgug4120a_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mgug4120a_dbconn()
  mgug4120a_dbfile()
  mgug4120a_dbschema(file="", show.indices=FALSE)
  mgug4120a_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mgug4120a_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mgug4120a_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mgug4120a_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mgug4120a_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mgug4120a_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mgug4120a_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mgug4120a_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mgug4120a_dbschema}: none (invisible \code{NULL}).

  \code{mgug4120a_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mgug4120a_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mgug4120a_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mgug4120a_dbfile(), cache_size=64000,
  synchronous=0)

  mgug4120a_dbschema()

  mgug4120a_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
